==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pl/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Więcej informacji",

    "audit_help" => "Zaznaczenie tego pola spowoduje edycję rekordu aktywów, aby odzwierciedlić tę nową lokalizację. Pozostawienie go niezaznaczone spowoduje po prostu odnotowanie lokalizacji w dzienniku audytu.<br><br>Zauważ, że ten zasób jest zablokowany, nie zmieni lokalizacji osoby, składnika aktywów lub miejsca, w którym jest ona kontrolowana.",

    'assets' => 'Aktywa są to elementy identyfikowane przez numer seryjny lub etykietę.  Są to przedmioty o większej wartości, gdzie liczy się identyfikacja określonego elementu.',

    'categories' => 'Kategorie pozwolą zorganizować twoje przedmioty. Przykłady kategorii to np. &quot; Stacje robocze&quot;, &quot;Laptopy&quot;, &quot;Telefony&quot;, &quot;Tablety&quot; itp., ale możesz używać kategorii w dowolny sensowny dla siebie sposób.',

    'accessories' => 'Akcesoria to rzeczy, które wydajesz użytkownikom, a które nie mają numerów seryjnych (lub nie zależy Ci na śledzeniu ich niepowtarzalności). Na przykład, myszki i klawiatury komputerowe.',

    'companies'     => 'Firmy mogą być używane jako proste pole identyfikacyjne lub mogą posłużyć do ograniczenia widoczności aktywów dla użytkowników itp. jeśli \'\'Wsparcie dla wielu firm" jest włączone w ustawieniach administracyjnych.',

    'components'    => 'Składniki są przedmioty, które są częścią aktywów np. dyski twarde, pamięci RAM, zasilacze do laptopów itp.',

    'consumables'   => 'Materiały eksploatacyjne są przedmiotami jednorazowego użytku, które będą wykorzystane w miarę upływu czasu. Przykładem będzie tusz do drukarki lub papier do kopiarek.',

    'depreciations' => 'Możesz ustawić amortyzację środków trwałych na podstawie amortyzacji aktywów w oparciu o metodę liniową.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pl/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Więcej informacji',

    'audit_help' => 'Zaznaczenie tego pola spowoduje edycję rekordu aktywów, aby odzwierciedlić tę nową lokalizację. Pozostawienie go niezaznaczone spowoduje po prostu odnotowanie lokalizacji w dzienniku audytu.<br><br>Zauważ, że ten zasób jest zablokowany, nie zmieni lokalizacji osoby, składnika aktywów lub miejsca, w którym jest ona kontrolowana.',

    'assets' => 'Aktywa są to elementy identyfikowane przez numer seryjny lub etykietę.  Są to przedmioty o większej wartości, gdzie liczy się identyfikacja określonego elementu.',

    'categories' => 'Kategorie pozwolą zorganizować twoje przedmioty. Przykłady kategorii to np. &quot; Stacje robocze&quot;, &quot;Laptopy&quot;, &quot;Telefony&quot;, &quot;Tablety&quot; itp., ale możesz używać kategorii w dowolny sensowny dla siebie sposób.',

    'accessories' => 'Akcesoria to rzeczy, które wydajesz użytkownikom, a które nie mają numerów seryjnych (lub nie zależy Ci na śledzeniu ich niepowtarzalności). Na przykład, myszki i klawiatury komputerowe.',

    'companies'     => 'Firmy mogą być używane jako proste pole identyfikacyjne lub mogą posłużyć do ograniczenia widoczności aktywów dla użytkowników itp. jeśli \'\'Wsparcie dla wielu firm" jest włączone w ustawieniach administracyjnych.',

    'components'    => 'Składniki są przedmioty, które są częścią aktywów np. dyski twarde, pamięci RAM, zasilacze do laptopów itp.',

    'consumables'   => 'Materiały eksploatacyjne są przedmiotami jednorazowego użytku, które będą wykorzystane w miarę upływu czasu. Przykładem będzie tusz do drukarki lub papier do kopiarek.',

    'depreciations' => 'Możesz ustawić amortyzację środków trwałych na podstawie amortyzacji aktywów w oparciu o metodę liniową.',

];
